:          PREPATH / POSTPATH / PUSHP / POPP / POPP2 / USEPATH
:
:   4DOS v. 4.0 aliases to let you manipulate your PATH more effectively.
:
:                  By Steve James,  CIS ID 70670,1025
:
:
:    PURPOSE: I don't like keeping a long PATH.  One way around this is
:             to let aliases do the work for you of manipulating your
:             PATH variable for you.  What I've done below is to provide
:             aliases that let you do the most common path manipulations.
:             ALSO, the PUSHP and POPP aliases work analogously to PUSHD
:             and POPD and let you push and pop paths off of a psuedo
:             "path stack".  PUSHP and POPP can be used together to make
:             a path change and then restore the former PATH without
:             having to type it back in or ESET it.
:
:
: HOW IT WORKS:  This "path stack" really is just new environment
:                variables created by the aliases to hold the old path
:                values. For instance, the aliases may create variables
:                like PATH1, PATH2, etc.  Also, a variable called
:                $PATHNUM is used to keep track of where the "top of the
:                stack" is.  PATH0 is never created, since this is where
:                I keep a backup copy of my original path. (I have found
:                this to be a good practice.)
:
:
:    ALSO: There is also are aliases below called PUSHP2 & USEPATH.
:          PUSHP2 is just a variation on PUSHP that allows you specify
:          a single directory as an argument and have it be placed at
:          the beginning of the new PATH.  USEPATH is an alias that was
:          inspired by Tom Rawson's (@ JP Software) "IN" alias.
:
:
:    A CREDIT: Tom Rawson's IN alias is listed below in order to allow
:              me to show how easy and useful it can be to combine it
:              w/ my USEPATH alias.
:
:
:
: First some useful helper aliases...
:
: INC & DEC can both handle more than one variable at a time:
:
:                    inc a b c   OR   inc a;b;c
:
inc=for %$v in (%&) set %$v=%@eval[%[%$v]+1]
dec=for %$v in (%&) set %$v=%@eval[%[%$v]-1]
:
:
: Now, some quickie path manipulation aliases...
:
prepath=path=%&;%path%
postpath=path=%path%;%&
:
:
: Now for PUSHP / PUSHP2 & POPP...
: As noted above, PUSHP2 is a variation of PUSHP.
:
pushp=inc $pathnum ^ set path%$pathnum%=%path% ^ if not "%&"=="" path=%&
:
pushp2=pushp %&;%path%
:
popp=iff not "%$pathnum%"=="" then ^ path=%[path%$pathnum%] ^ unset path%$pathnum% ^ dec $pathnum ^ if "%$pathnum%"=="0" unset $pathnum ^ else ^ echo PATH stack is empty! ^ endiff
:
:
: Note that in my USEPATH alias below I like to use the PUSHP2 variation
:                          (saves space)
:
usepath=pushp2 %1^%2&^popp
:
: Now for Tom Rawson's IN alias...
:
in=pushd %1^%2&^popd
:
:
: Now for some examples:
:
: (Note that the directories specified below will be prepended to the
:       existing paths, since USEPATH is using PUSHP2)
:
:
:   Borland C++
bc=in c:\bc\cfiles usepath c:\bc *bc %&
:
:   Word for Windows
winword=in c:\windows\winword usepath c:\windows *winword %&
